@@ -1,9 +1,12 @@
+import ipih
+
+from enum import Enum
+from collections import namedtuple
 from dataclasses import dataclass, field
 from datetime import datetime, timedelta, date
-from enum import Enum
-from typing import Any, Tuple, List, Callable, TypeVar, Generic
-from collections import namedtuple
+from typing import Any, Tuple, List, Callable, TypeVar, Generic, TypeAlias
 
+strdict: TypeAlias = dict[str, Any]
 
 @dataclass
 class Host:
@@ -31,13 +34,66 @@ class ZabbixHost:
 
 
 @dataclass
-class ZabbixValue:
+class IOTDevice:
+    name: str | None = None
+    id: str | None = None
+    key: str | None = None
+    mac: str | None = None
+    uuid: str | None = None
+    sn: str | None = None
+    category: str | None = None
+    product_name: str | None = None
+    product_id: str | None = None
+    biz_type: int | None = None
+
+
+@dataclass
+class IOTDeviceStatusProperty:
+    code: str | None = None
+    name: str | None = None
+    type: str | None = None
+    unit: str | None = None
+
+
+@dataclass
+class IOTDeviceStatusIntegerProperty(IOTDeviceStatusProperty):
+
+    min: int | float | None = None
+    max: int | float | None = None
+    scale: int | float | None = None
+    step: int | float | None = None
+
+
+"""
+@dataclass
+class IOTDeviceStatusProperty:
+    code: str | None = None
+    name: str | None = None
+    type: str | None = None
+    values: tuple[IOTDeviceStatusPropertyValue, ...] | None = None
+"""
+
+
+@dataclass
+class IOTDeviceStatusValue:
+    code: str | None = None
+    value: Any = None
+
+
+@dataclass
+class IOTDeviceStatus:
+    timestamp: int = 0
+    values: tuple[IOTDeviceStatusValue, ...] | None = None
+
+
+@dataclass
+class ZabbixMetricsValue:
     value: Any | None = None
     clock: datetime | int | None = None
 
 
 @dataclass
-class ZabbixItem:
+class ZabbixMetrics:
     itemid: int | None = None
     type: int = 0
     snmp_oid: str | None = None
@@ -231,6 +287,7 @@ class Result(Generic[T]):
         return len(self.data)
 
     def __iadd__(self, value):
+        self.data = self.data or []
         if (
             isinstance(value, Result)
             and isinstance(self.data, list)
@@ -272,6 +329,10 @@ class User(UserBase):
     mail: str | None = None
     telephoneNumber: str | None = None
     userAccountControl: int | None = None
+    
+    @property
+    def login(self) -> str:
+        return self.samAccountName
 
 
 Rect = namedtuple("Rect", ["left", "top", "width", "height"])
@@ -364,6 +425,10 @@ class ComputerDescription:
 class Computer(ComputerDescription):
     samAccountName: str | None = None
     accessable: bool | None = None
+    
+    @property
+    def login(self) -> str:
+        return self.samAccountName
 
 
 @dataclass
@@ -388,6 +453,21 @@ class ResourceDescriptionDelegated(ResourceDescription):
     delegator: str | None = None
 
 
+@dataclass
+class ZabbixResourceDescription(ResourceDescription):
+    zabbix_host_name: str | None = None
+
+    def get_zabbix_host_name(self) -> str:
+        return self.zabbix_host_name or self.address
+
+
+@dataclass
+class ZabbixResourceDescriptionDelegated(
+    ZabbixResourceDescription, ResourceDescriptionDelegated
+):
+    pass
+
+
 @dataclass
 class SiteResourceDescription(ResourceDescription):
     check_certificate_status: bool = False
@@ -425,7 +505,7 @@ class DiskStatistics:
 
 
 @dataclass
-class DisksResourceStatus(IResourceStatus):
+class DisksStatisticsStatus(IResourceStatus):
     host: str | None = None
     disk_list: list[DiskStatistics] = field(default_factory=list)
 
@@ -489,6 +569,7 @@ class PolibasePersonVisitDS(PolibasePersonBase):
     doctorID: int | None = None
     doctorFullName: str | None = None
     serviceGroupID: int | None = None
+    comment: str | None = None
 
 
 @dataclass
@@ -520,7 +601,7 @@ class PolibasePersonVisitNotificationDS:
 @dataclass
 class EventDS:
     name: str | None = None
-    parameters: dict | None = None
+    parameters: strdict | None = None
     timestamp: datetime | date | str | int | None = None
     id: int = 0
 
@@ -530,6 +611,8 @@ class Message:
     message: str | None = None
     recipient: str | None = None
     sender: str | None = None
+    image_url: str | None = None
+    location: tuple[float, float] | None = None
 
 
 @dataclass
@@ -575,6 +658,7 @@ class PolibasePersonVisit(PolibasePersonVisitDS):
     completeDate: datetime | None = None
     beginDate2: datetime | None = None
     completeDate2: datetime | None = None
+    Comment: str | None = None
 
 
 @dataclass
@@ -689,26 +773,29 @@ class TimeTrackingResultByDivision:
 @dataclass
 class RobocopyJobDescription:
     name: str | None = None
-    start_datetime: str | None = None
+    start_cron_string: str | None = None
     host: str | None = None
     run_from_system_account: bool = False
     run_with_elevetion: bool = False
     live: bool = False
+    exclude: bool = False
 
     def clone(
         self,
         job_name: str,
-        start_datetime: str | None = None,
+        start_cron_string: str | None = None,
         host: str | None = None,
         live: bool | None = None,
+        exclude: bool = False,
     ):
         return RobocopyJobDescription(
             job_name,
-            start_datetime,
+            start_cron_string,
             host or self.host,
             self.run_from_system_account,
             self.run_with_elevetion,
             self.live if live is None else live,
+            self.exclude if exclude is None else exclude,
         )
 
 
@@ -728,6 +815,7 @@ class RobocopyJobStatus:
     last_status: int | None = None
     live: bool = False
     pid: int = -1
+    exclude: bool = False
 
 
 @dataclass
@@ -798,7 +886,6 @@ class File:
 
 @dataclass
 class Note(File):
-    id: str | None = None
     images: list[str] | None = None
 
 
@@ -993,6 +1080,18 @@ class IntStorageVariableHolder(StorageVariableHolder):
     default_value: int = 0
 
 
+@dataclass
+class VariantableStorageVariable:
+    variants: tuple[Any, ...]| None = None
+
+
+@dataclass
+class IntVariantableStorageVariableHolder(
+    VariantableStorageVariable, IntStorageVariableHolder
+):
+    variants: tuple[int, ...] | None = None
+
+
 @dataclass
 class MinIntStorageVariableHolder(IntStorageVariableHolder):
     min_value: int = 0
@@ -1105,12 +1204,13 @@ class JournalRecord:
 
 @dataclass
 class BonusInformation:
-    all: float = 0
-    spent: float = 0
-    active: float = 0
-    last_money_spent: float = 0
-    last_spent: float = 0
-    last: float = 0
+    bonus_all: float = 0
+    money_all: float = 0
+    bonus_spent_all: float = 0
+    bonus_active: float = 0
+    money_last: float = 0
+    bonus_last_spent: float = 0
+    bonus_last: float = 0
 
 
 @dataclass
