@@ -1,6 +1,6 @@
 from enum import Enum, auto, IntEnum
 
-from pih.tools import j
+from pih.tools import j, js
 from pih.consts import *
 from pih.consts.names import *
 from pih.consts.paths import *
@@ -9,22 +9,18 @@ from pih.collections import (
     ResourceDescription,
     MedicalResearchType,
     SiteResourceDescription,
+    ZabbixResourceDescription,
     MinIntStorageVariableHolder,
     ResourceDescriptionDelegated,
     OrderedNameCaptionDescription,
+    ZabbixResourceDescriptionDelegated,
     IconedOrderedNameCaptionDescription,
 )
 from pih.consts.password import *
 from pih.consts.date_time import *
 from pih.consts.service_commands import *
 
-VERSION: str = "0.20"
-
-EMAIL_SPLITTER: str = "@"
-ISOLATED_ARG_NAME: str = "isolated"
-ARGUMENT_PREFIX: str = "--"
-SPLITTER: str = ":"
-UNKNOWN: str = "?"
+VERSION: str = "0.37.7.1"
 
 
 class DATA:
@@ -72,6 +68,11 @@ class FONT:
 
 class SessionFlags(IntEnum):
     CLI = 512
+    OUTSIDE = 8192
+    
+class SESSION_TYPE:
+    MOBILE: str = "mobile"
+    OUTSIDE: str = "outside"
 
 
 class URLS:
@@ -81,7 +82,7 @@ class URLS:
 class EmailVerificationMethods(IntEnum):
     NORMAL = auto()
     ABSTRACT_API = auto()
-    DEFAULT = NORMAL
+    DEFAULT = ABSTRACT_API
 
 
 class ROBOCOPY:
@@ -101,6 +102,17 @@ class ROBOCOPY:
     }
 
 
+class CHARSETS:
+    WINDOWS_ALTERNATIVE: str = "CP866"
+    UTF8: str = "utf-8"
+    
+class INPUT_TYPE:
+    NO: int = -1
+    NORMAL: int = 0
+    INDEX: int = 1
+    QUESTION: int = 2
+
+
 class WINDOWS:
 
     NAME: str = "Windows"
@@ -111,7 +123,7 @@ class WINDOWS:
     ENVIROMENT_COMMAND: str = "$Env"
 
     class CHARSETS:
-        ALTERNATIVE: str = "CP866"
+        ALTERNATIVE: str = CHARSETS.WINDOWS_ALTERNATIVE
 
     class SERVICES:
         WIA: str = (
@@ -124,21 +136,37 @@ class WINDOWS:
 
     class PORT:
         SMB: int = 445
-
+        
 
 class CONST(DATE_TIME):
 
+    class ADDRESS:
+
+        LOCATION: tuple[float, float] = (43.10077173904819, 131.90206595788635)
+        TEXT: str = (
+            "- г. Владивосток, ул. Запорожская, 7\n- Поликлиника: пн-сб с 8 до 20\n- Приемное отделение: круглосуточно, без праздников и выходных"
+        )
+
+    EMAIL_SPLITTER: str = "@"
+    ISOLATED_ARG_NAME: str = "isolated"
+    ARGUMENT_PREFIX: str = "--"
+    SPLITTER: str = ":"
+    NAME_SPLITTER: str = "_"
+    UNKNOWN_VALUE: str = "?"
+
     class PORT:
         HTTP: int = 80
+        HTTPS: int = 443
         SMTP: int = 587
         IMAP: int = 993
+        SNMP: int = 161
 
     class FILES:
         SECTION: str = "Мобильные файлы"
 
     class NOTES:
         SECTION: str = "Мобильные заметки"
-        
+
     class JOURNALS:
         SECTION: str = "Журналы"
 
@@ -151,7 +179,7 @@ class CONST(DATE_TIME):
         WORKSTATION_MAME: str = Hosts.DEVELOPER.NAME
         USER: str | None = "nak"
         EMAIL_ADDRESS: str | None = "nak@pacifichosp.com"
-        PIN: int = 117276
+        PIN: int = 100310
         NAME: str = "test"
 
     GROUP_PREFIX: str = "group:"
@@ -160,7 +188,7 @@ class CONST(DATE_TIME):
     UNTRUST_SITE_PROTOCOL: str = "http://"
 
     INTERNATIONAL_TELEPHONE_NUMBER_PREFIX: str = "7"
-    TELEPHONE_NUMBER_PREFIX: str = f"+{INTERNATIONAL_TELEPHONE_NUMBER_PREFIX}"
+    TELEPHONE_NUMBER_PREFIX: str = j(("+", INTERNATIONAL_TELEPHONE_NUMBER_PREFIX))
     INTERNAL_TELEPHONE_NUMBER_PREFIX: str = "тел."
 
     class CACHE:
@@ -181,9 +209,10 @@ class CONST(DATE_TIME):
             SITE_NAME: str = "https://wa.me/"
             SEND_MESSAGE_TO_TEMPLATE: str = SITE_NAME + "{}?text={}"
             GROUP_SUFFIX: str = "@g.us"
+            OUTSIDE_SUFFIX: str = "@outside"
+            CLI_SUFFIX: str = "@cli"
 
             class GROUP(Enum):
-                # IT: str = "120363163438805316@g.us"
                 PIH_CLI = "120363163438805316@g.us"
                 REGISTRATOR_CLI = "120363212130686795@g.us"
                 RD = "79146947050-1595848245@g.us"
@@ -197,27 +226,36 @@ class CONST(DATE_TIME):
                 SCANNED_DOCUMENT_HELPER_CLI = "120363220286578760@g.us"
 
             class WAPPI:
-                
 
                 DATETIME_FORMAT: str = "%Y-%m-%dT%H:%M:%SZ"
                 NAME: str = "Wappi"
                 DESCRIPTION: str = "Сервис по отправке сообщений"
-                
+                SEND: str = "send?"
+
                 PROFILE_SUFFIX: str = "profile_id="
                 URL_API: str = "https://wappi.pro/api"
-                URL_API_SYNC: str = f"{URL_API}/sync"
-                URL_MESSAGE: str = f"{URL_API_SYNC}/message"
-                STATUS: str = j((j((URL_API_SYNC, "get", "status"), "/"), "?", PROFILE_SUFFIX))
-                URL_SEND_MESSAGE: str = f"{URL_MESSAGE}/send?{PROFILE_SUFFIX}"
-                URL_SEND_VIDEO: str = f"{URL_MESSAGE}/video/send?{PROFILE_SUFFIX}"
-                URL_SEND_IMAGE: str = f"{URL_MESSAGE}/img/send?{PROFILE_SUFFIX}"
-                URL_SEND_DOCUMENT: str = f"{URL_MESSAGE}/document/send?{PROFILE_SUFFIX}"
-                URL_SEND_LIST_MESSAGE: str = f"{URL_MESSAGE}/list/send?{PROFILE_SUFFIX}"
-                URL_SEND_BUTTONS_MESSAGE: str = (
-                    f"{URL_MESSAGE}/buttons/send?{PROFILE_SUFFIX}"
+                URL_API_SYNC: str = j((URL_API, "/sync"))
+                URL_MESSAGE: str = j((URL_API_SYNC, "/message"))
+                STATUS: str = j(
+                    (j((URL_API_SYNC, "get", "status"), "/"), "?", PROFILE_SUFFIX)
                 )
-                URL_GET_MESSAGES: str = f"{URL_MESSAGE}s/get?{PROFILE_SUFFIX}"
-                URL_GET_STATUS: str = f"{URL_API_SYNC}/get/status?{PROFILE_SUFFIX}"
+                URL_SEND_MESSAGE: str = j((URL_MESSAGE, "/", SEND, PROFILE_SUFFIX))
+                URL_SEND_LOCATION: str = j(
+                    (URL_MESSAGE, "/location/", SEND, PROFILE_SUFFIX)
+                )
+                URL_SEND_VIDEO: str = j((URL_MESSAGE, "/video/", SEND, PROFILE_SUFFIX))
+                URL_SEND_IMAGE: str = j((URL_MESSAGE, "/img/", SEND, PROFILE_SUFFIX))
+                URL_SEND_DOCUMENT: str = j(
+                    (URL_MESSAGE, "/document/", SEND, PROFILE_SUFFIX)
+                )
+                URL_SEND_LIST_MESSAGE: str = j(
+                    (URL_MESSAGE, "/list/", SEND, PROFILE_SUFFIX)
+                )
+                URL_SEND_BUTTONS_MESSAGE: str = j(
+                    (URL_MESSAGE, "/buttons/", SEND, PROFILE_SUFFIX)
+                )
+                URL_GET_MESSAGES: str = j((URL_MESSAGE, "s/get?", PROFILE_SUFFIX))
+                URL_GET_STATUS: str = j((URL_API_SYNC, "/get/status?", PROFILE_SUFFIX))
                 CONTACT_SUFFIX: str = "@c.us"
 
                 class Profiles(Enum):
@@ -232,20 +270,6 @@ class CONST(DATE_TIME):
                     Profiles.CALL_CENTRE: "7d453de6fc17d3e6816b0abc46f2b192822130f5",
                 }
 
-    class PYTHON:
-        EXECUTOR_ALIAS: str = "py"
-        EXECUTOR: str = "python"
-        EXECUTOR3: str = "python3"
-        PYPI: str = "pip"
-        SEARCH_PATTERN: str = "\\Python\\Python"
-
-        class COMMAND:
-            VERSION: str = "--version"
-            INSTALL: str = "install"
-            UNINSTALL: str = "uninstall"
-            SHOW: str = "show"
-            FLAG: str = "-c"
-
     class SERVICE:
         NAME: str = "service"
 
@@ -307,6 +331,7 @@ class CONST(DATE_TIME):
         WAIT: str = "⏳"
         NOTIFICATION: str = "🔔"
         ROBOT: str = "🤖"
+        SAD: str = "😔"
         GOOD: str = YES
         ERROR: str = NO
         ORANGE_ROMB: str = "🔸"
@@ -344,8 +369,8 @@ class MATERIALIZED_RESOURCES:
     NAME: str = "MATERIALIZED_RESOURCES"
     ALIAS: str = "MR"
 
-    class TYPES(Enum):
-        
+    class Types(Enum):
+
         CHILLER_FILTER = MinIntStorageVariableHolder(
             "CHF", description="Фильтры для чиллера", min_value=2
         )
@@ -384,8 +409,14 @@ class RESOURCES:
             "192.168.5.3", "VPN соединение для PACS SPB", (2, 100, 5), Hosts.WS255.NAME
         )
 
-        PACS_SPB: ResourceDescriptionDelegated = ResourceDescriptionDelegated(
-            "10.76.12.124:4242", "Соединение PACS SPB", (2, 100, 5), Hosts.WS255.NAME
+        PACS_SPB: ZabbixResourceDescriptionDelegated = (
+            ZabbixResourceDescriptionDelegated(
+                "10.76.12.124:4242",
+                "Соединение PACS SPB",
+                (2, 100, 5),
+                Hosts.WS255.NAME,
+                "PACS_SPB",
+            )
         )
 
         POLIBASE1: ResourceDescription = ResourceDescription(
@@ -400,16 +431,17 @@ class RESOURCES:
             inaccessibility_check_values=(2, 10000, 15),
         )
 
-        POLIBASE: ResourceDescription = ResourceDescription(
-            Hosts.POLIBASE.ALIAS,
-            "Polibase",
-            inaccessibility_check_values=(2, 10000, 15),
+        POLIBASE: ZabbixResourceDescription = ZabbixResourceDescription(
+            POLIBASE1.address,
+            POLIBASE1.name,
+            POLIBASE1.inaccessibility_check_values,
+            Hosts.POLIBASE1.ALIAS,
         )
 
         SITE_LIST: list[SiteResourceDescription] = [
             SiteResourceDescription(
                 ADDRESSES.SITE_ADDRESS,
-                f"Сайт компании: {ADDRESSES.SITE_ADDRESS}",
+                js(("Сайт компании:", ADDRESSES.SITE_ADDRESS)),
                 inaccessibility_check_values=(1, 20, 15),
                 check_certificate_status=True,
                 check_free_space_status=True,
@@ -417,36 +449,39 @@ class RESOURCES:
             ),
             SiteResourceDescription(
                 ADDRESSES.EMAIL_SERVER_ADDRESS,
-                f"Сайт корпоративной почты: {ADDRESSES.EMAIL_SERVER_ADDRESS}",
+                js(("Сайт корпоративной почты:", ADDRESSES.EMAIL_SERVER_ADDRESS)),
                 check_certificate_status=True,
                 check_free_space_status=True,
                 driver_name="/dev/mapper/centos_tenant26--02-var",
             ),
             SiteResourceDescription(
                 ADDRESSES.API_SITE_ADDRESS,
-                f"Api сайта {ADDRESSES.SITE_ADDRESS}: {ADDRESSES.API_SITE_ADDRESS}",
+                js(
+                    (
+                        "Api сайта",
+                        j((ADDRESSES.SITE_ADDRESS, ":")),
+                        ADDRESSES.API_SITE_ADDRESS,
+                    )
+                ),
                 check_certificate_status=True,
                 check_free_space_status=False,
             ),
             SiteResourceDescription(
-                ADDRESSES.BITRIX_SITE_URL, f"Сайт ЦМРТ24: {ADDRESSES.BITRIX_SITE_URL}"
+                ADDRESSES.BITRIX_SITE_URL,
+                js(("Сайт ЦМРТ24:", ADDRESSES.BITRIX_SITE_URL)),
             ),
             SiteResourceDescription(
                 ADDRESSES.OMS_SITE_ADDRESS,
-                f"Внутренний сайт омс: {ADDRESSES.OMS_SITE_ADDRESS}",
+                js(("Внутренний сайт омс:", ADDRESSES.OMS_SITE_ADDRESS)),
                 internal=True,
             ),
             SiteResourceDescription(
                 ADDRESSES.WIKI_SITE_ADDRESS,
-                f"Внутренний сайт Вики: {ADDRESSES.WIKI_SITE_ADDRESS}",
+                js(("Внутренний сайт Вики:", ADDRESSES.WIKI_SITE_ADDRESS)),
                 internal=True,
             ),
         ]
 
-    class InaccessableReasons(Enum):
-        CERTIFICATE_ERROR = "Ошибка проверки сертификата"
-        SERVICE_UNAVAILABLE = "Ошибка 503: Сервис недоступен"
-
 
 class CheckableSections(IntEnum):
     RESOURCES = auto()
@@ -473,6 +508,11 @@ class MarkType(IntEnum):
     TEMPORARY = auto()
 
 
+class MARK_VARIANT:
+    BRACELET: str = "-0-"
+    CARD: str = ""
+
+
 class PolibasePersonInformationQuestStatus(IntEnum):
     UNKNOWN = -1
     GOOD = 0
@@ -508,6 +548,7 @@ class CommandTypes(Enum):
     )
     DATA_SOURCE = ("Запрос к базе данных DataSource (DS)", "ds")
     CMD = ("Консольную команду", "cmd")
+    POWERSHELL = ("Powershell команду", "powershell")
     PYTHON = ("Скрипт Python", "py", "python")
     SSH = ("Команда SSH", "ssh")
 
@@ -653,7 +694,7 @@ class Actions(Enum):
     DOOR_OPEN = ActionDescription(
         "DOOR_OPEN",
         ("door_open",),
-        "Открытие дверей",
+        "Открыть {name} дверь",
         "Открыть",
         False,
         False,
@@ -662,7 +703,7 @@ class Actions(Enum):
     DOOR_CLOSE = ActionDescription(
         "DOOR_CLOSE",
         ("door_close",),
-        "Закрытие дверей",
+        "Закрыть {name} дверь",
         "Закрыть",
         False,
         False,
@@ -694,76 +735,87 @@ class STATISTICS:
         CT_DAY = "CT_DAY"
         CT_WEEK = "CT_WEEK"
         CT_MONTH = "CT_MONTH"
-        CHILLER_FILTER = MATERIALIZED_RESOURCES.TYPES.CHILLER_FILTER.name
+        CHILLER_FILTER = MATERIALIZED_RESOURCES.Types.CHILLER_FILTER.name
         MRI_COLDHEAD = "MRI_COLDHEAD"
         POLIBASE_DATABASE_DUMP = "POLIBASE_DATABASE_DUMP"
         POLIBASE_PERSON_REVIEW_NOTIFICATION = "POLIBASE_PERSON_REVIEW_NOTIFICATION"
 
 
 class JournalType(tuple[int, OrderedNameCaptionDescription], Enum):
-    TEST = (
+    GENERAL = (
         0,
-        OrderedNameCaptionDescription("test", "Тест"),
+        OrderedNameCaptionDescription("general", "Общий", order=1),
     )
     COMPUTER = (
         1,
-        OrderedNameCaptionDescription("computer", "Компьютер"),
+        OrderedNameCaptionDescription("computer", "Компьютер", order=2),
     )
     MRI_CHILLER = (
         2,
-        OrderedNameCaptionDescription("mri_chiller", "Чиллер МРТ"),
+        OrderedNameCaptionDescription("mri_chiller", "Чиллер МРТ", order=4),
     )
     MRI_GRADIENT_CHILLER = (
         3,
-        OrderedNameCaptionDescription("mri_gradient_chiller", "Чиллер градиентов МРТ"),
+        OrderedNameCaptionDescription(
+            "mri_gradient_chiller", "Чиллер градиентов МРТ", order=5
+        ),
     )
     MRI_CLOSET_CHILLER = (
         4,
-        OrderedNameCaptionDescription("mri_closet_chiller", "Чиллер кабинета МРТ"),
-    )
-    CHILLER = (
-        5,
-        OrderedNameCaptionDescription("chiller", "Чиллер"),
+        OrderedNameCaptionDescription(
+            "mri_closet_chiller", "Чиллер кабинета МРТ", order=6
+        ),
     )
+    CHILLER = (5, OrderedNameCaptionDescription("chiller", "Чиллер", order=3))
     COMMUNICATION_ROOM = (
         6,
-        OrderedNameCaptionDescription("communication_room", "Коммутационная комната"),
+        OrderedNameCaptionDescription(
+            "communication_room", "Коммутационная комната", order=10
+        ),
     )
     SERVER_ROOM = (
         7,
-        OrderedNameCaptionDescription("server_room", "Серверная комната"),
+        OrderedNameCaptionDescription("server_room", "Серверная комната", order=9),
     )
     MRI_TECHNICAL_ROOM = (
         8,
-        OrderedNameCaptionDescription("mri_technical_room", "Техническая комната МРТ"),
+        OrderedNameCaptionDescription(
+            "mri_technical_room", "Техническая комната МРТ", order=7
+        ),
     )
     MRI_PROCEDURAL_ROOM = (
         9,
-        OrderedNameCaptionDescription("mri_procedural_room", "Процедурная комната МРТ"),
+        OrderedNameCaptionDescription(
+            "mri_procedural_room", "Процедурная комната МРТ", order=9
+        ),
     )
     PRINTER = (
         10,
-        OrderedNameCaptionDescription("printer", "Принтер"),
+        OrderedNameCaptionDescription("printer", "Принтер", order=11),
     )
     SERVER = (
         11,
-        OrderedNameCaptionDescription("server", "Сервер"),
+        OrderedNameCaptionDescription("server", "Сервер", order=12),
     )
     OUTSIDE_SERVER = (
         12,
-        OrderedNameCaptionDescription("outside_server", "Внешний сервер"),
+        OrderedNameCaptionDescription("outside_server", "Внешний сервер", order=13),
     )
     AGREEMENT = (
         13,
-        OrderedNameCaptionDescription("agreement", "Договор и счет"),
+        OrderedNameCaptionDescription("agreement", "Договор и счет", order=14),
     )
     XRAY = (
         14,
-        OrderedNameCaptionDescription("xray", "Рентген"),
+        OrderedNameCaptionDescription("xray", "Рентген", order=15),
     )
     CASH_REGISTER = (
         15,
-        OrderedNameCaptionDescription("cash_register", "Касса"),
+        OrderedNameCaptionDescription("cash_register", "Касса", order=16),
+    )
+    CT = (
+        16,
+        OrderedNameCaptionDescription("ct", "КТ", order=2),
     )
 
 
