@@ -8,21 +8,18 @@ class Events(Enum):
     DEBUG = EventDescription(
         "It is a debug event", LogMessageChannels.DEBUG, LogMessageFlags.DEBUG
     )
-    
-    ERROR = (
-        EventDescription(
-            "{}",
-            LogMessageChannels.DEBUG,
-            LogMessageFlags.ERROR,
-            (
-                PARAM_ITEMS.TEXT,
-                PARAM_ITEMS.HOST.configurate(visible=False),
-                PARAM_ITEMS.TYPE.configurate(visible=False),
-                PARAM_ITEMS.ARGUMENTS.configurate(visible=False),
-            ),
-        )
-    )
 
+    ERROR = EventDescription(
+        "{}",
+        LogMessageChannels.DEBUG,
+        LogMessageFlags.ERROR,
+        (
+            PARAM_ITEMS.TEXT,
+            PARAM_ITEMS.HOST.configurate(visible=False),
+            PARAM_ITEMS.TYPE.configurate(visible=False),
+            PARAM_ITEMS.ARGUMENTS.configurate(visible=False),
+        ),
+    )
 
     PRINTER_REPORT = EventDescription(
         "Принтер {printer_name} ({location}):\n {printer_report}",
@@ -87,7 +84,7 @@ class Events(Enum):
             ParamItem("service_information", "Service information"),
         ),
     )
-    
+
     SERVICE_IS_BEING_STARTED = EventDescription(
         "Сервис {service_name} запускается!\nИмя хоста: {host_name}\nПорт: {port}",
         LogMessageChannels.SERVICES,
@@ -95,7 +92,7 @@ class Events(Enum):
         (
             PARAM_ITEMS.SERVICE_NAME,
             ParamItem("host_name", "Name of host"),
-            ParamItem("port", "Port")
+            ParamItem("port", "Port"),
         ),
     )
 
@@ -467,6 +464,13 @@ class Events(Enum):
         (PARAM_ITEMS.NAME, PARAM_ITEMS.PIN, PARAM_ITEMS.VALUE),
     )
 
+    POLIBASE_PERSON_ANSWERED = EventDescription(
+        "Клиент: {} ({}) ответил: \"{}\" на получение ссылки",
+        LogMessageChannels.POLIBASE,
+        (LogMessageFlags.NOTIFICATION, LogMessageFlags.SAVE),
+        (PARAM_ITEMS.PIN, PARAM_ITEMS.TELEPHONE_NUMBER, PARAM_ITEMS.VALUE),
+    )
+
     MAIL_TO_POLIBASE_PERSON_WAS_SENT = EventDescription(
         "Почта с медицинской записью {id} была отправлена пациенту: {pin}",
         LogMessageChannels.POLIBASE,
@@ -481,35 +485,33 @@ class Events(Enum):
         (PARAM_ITEMS.NAME, PARAM_ITEMS.PIN, PARAM_ITEMS.VALUE),
     )
 
-    POLIBASE_PERSON_VISIT_NOTIFICATION_WAS_REGISTERED = (
-        EventDescription(
-            "Зарегистрировано новое уведомление о посещении: {name} ({type_string})",
-            LogMessageChannels.POLIBASE,
-            LogMessageFlags.SILENCE,
-            (
-                PARAM_ITEMS.NAME,
-                ParamItem("type_string", ""),
-                ParamItem("notification", ""),
-            ),
-        )
+    POLIBASE_PERSON_VISIT_NOTIFICATION_WAS_REGISTERED = EventDescription(
+        "Зарегистрировано новое уведомление о посещении: {name} ({type_string})",
+        LogMessageChannels.POLIBASE,
+        LogMessageFlags.SILENCE,
+        (
+            PARAM_ITEMS.NAME,
+            ParamItem("type_string", ""),
+            ParamItem("notification", ""),
+        ),
     )
 
-    POLIBASE_PERSON_REVIEW_NOTIFICATION_WAS_REGISTERED = (
-        EventDescription(
-            None,
-            LogMessageChannels.POLIBASE,
-            (LogMessageFlags.SAVE_ONCE, LogMessageFlags.SILENCE),
-            (PARAM_ITEMS.PERSON_PIN.configurate(key=True), PARAM_ITEMS.INPATIENT),
-        )
+    POLIBASE_PERSON_REVIEW_NOTIFICATION_WAS_REGISTERED = EventDescription(
+        None,
+        LogMessageChannels.POLIBASE,
+        (LogMessageFlags.SAVE_ONCE, LogMessageFlags.SILENCE),
+        (PARAM_ITEMS.PERSON_PIN.configurate(key=True), PARAM_ITEMS.INPATIENT),
     )
 
-    POLIBASE_PERSON_REVIEW_NOTIFICATION_WAS_ANSWERED = (
-        EventDescription(
-            "Пациент ({}) ответил на уведомление об отзыве: {}",
-            LogMessageChannels.POLIBASE,
-            LogMessageFlags.SAVE_ONCE,
-            (PARAM_ITEMS.PERSON_PIN.configurate(key=True), PARAM_ITEMS.STATUS),
-        )
+    POLIBASE_PERSON_REVIEW_NOTIFICATION_WAS_ANSWERED = EventDescription(
+        "Клиент: {}, ответил на уведомление об отзыве: \"{}\" ({})",
+        LogMessageChannels.POLIBASE,
+        LogMessageFlags.SAVE,
+        (
+            PARAM_ITEMS.PERSON_PIN.configurate(key=True),
+            PARAM_ITEMS.VALUE,
+            PARAM_ITEMS.STATUS,
+        ),
     )
 
     POLIBASE_PERSONS_WITH_OLD_FORMAT_BARCODE_WAS_DETECTED = EventDescription(
@@ -519,17 +521,25 @@ class Events(Enum):
         (PARAM_ITEMS.PERSON_PIN,),
     )
 
-    POLIBASE_PERSON_BARCODES_WITH_OLD_FORMAT_WERE_CREATED = (
-        EventDescription(
-            "Полибейс: все новые штрих-коды созданы",
-            LogMessageChannels.POLIBASE,
-            LogMessageFlags.SILENCE,
-            (PARAM_ITEMS.PERSON_PIN,),
-        )
+    POLIBASE_PERSON_BONUS_CARD_WAS_CREATED = EventDescription(
+        "Бонусная карта для клиента {} была создана",
+        LogMessageChannels.POLIBASE,
+        (LogMessageFlags.NOTIFICATION, LogMessageFlags.SAVE),
+        (
+            PARAM_ITEMS.PERSON_PIN.configurate(key=True),
+            ParamItem("url", "").configurate(visible=False),
+        ),
+    )
+
+    POLIBASE_PERSON_BARCODES_WITH_OLD_FORMAT_WERE_CREATED = EventDescription(
+        "Все штрих-коды для новых клиентов созданы",
+        LogMessageChannels.POLIBASE,
+        LogMessageFlags.SILENCE,
+        (PARAM_ITEMS.PERSON_PIN,),
     )
 
     POLIBASE_PERSON_WITH_INACCESSABLE_EMAIL_WAS_DETECTED = EventDescription(
-        "Пациент {} ({}) имеет недоступную электронную почту: {}. Регистратор: {}, компьютер: {} ({})",
+        "Клиент {} ({}) имеет недоступную электронную почту: {}. Регистратор: {}, компьютер: {} ({})",
         LogMessageChannels.POLIBASE_ERROR,
         LogMessageFlags.SAVE,
         (
@@ -543,7 +553,7 @@ class Events(Enum):
     )
 
     POLIBASE_PERSON_EMAIL_WAS_ADDED = EventDescription(
-        "Электронная почта пациента {} ({}): {} была добавлена",
+        "Электронная почта клиента {} ({}): {} была добавлена",
         LogMessageChannels.POLIBASE,
         (LogMessageFlags.RESULT, LogMessageFlags.SAVE),
         (
@@ -554,7 +564,7 @@ class Events(Enum):
     )
 
     ASK_FOR_POLIBASE_PERSON_EMAIL = EventDescription(
-        "Запрос электронной почта у пациента {} ({}). Локально: {}",
+        "Запрос электронной почта у клиента {} ({}). Локально: {}",
         LogMessageChannels.POLIBASE,
         (LogMessageFlags.NOTIFICATION, LogMessageFlags.SEND_ONCE),
         (
@@ -566,7 +576,7 @@ class Events(Enum):
     )
 
     POLIBASE_PERSON_BONUSES_WAS_UPDATED = EventDescription(
-        "Бонусы пациента {} обновились",
+        "Бонусы клиента {} обновились",
         LogMessageChannels.POLIBASE,
         (LogMessageFlags.NOTIFICATION, LogMessageFlags.SILENCE),
         (PARAM_ITEMS.PERSON_PIN,),
@@ -608,25 +618,25 @@ class Events(Enum):
         ),
     )
 
-    CARD_REGISTRY_FOLDER_WAS_SET_FOR_POLIBASE_PERSON = (
-        EventDescription(
-            'Карта пациента: {} добавлена в папку "{}".\nДействие совершил: {} ({})',
-            LogMessageChannels.CARD_REGISTRY,
-            LogMessageFlags.SAVE_ONCE,
-            (
-                PARAM_ITEMS.PERSON_PIN.configurate(key=True),
-                PARAM_ITEMS.CARD_REGISTRY_FOLDER,
-                PARAM_ITEMS.REGISTRATOR_PERSON_NAME,
-                PARAM_ITEMS.REGISTRATOR_PERSON_PIN,
-            ),
-        )
-    )
-
-    CARD_REGISTRY_FOLDER_WAS_SET_NOT_FROM_POLIBASE_FOR_POLIBASE_PERSON = EventDescription(
-        "Карта пациента: {} добавлена не с помощью Полибейс",
+    CARD_REGISTRY_FOLDER_WAS_SET_FOR_POLIBASE_PERSON = EventDescription(
+        'Карта пациента: {} добавлена в папку "{}".\nДействие совершил: {} ({})',
         LogMessageChannels.CARD_REGISTRY,
         LogMessageFlags.SAVE_ONCE,
-        (PARAM_ITEMS.PERSON_PIN,),
+        (
+            PARAM_ITEMS.PERSON_PIN.configurate(key=True),
+            PARAM_ITEMS.CARD_REGISTRY_FOLDER,
+            PARAM_ITEMS.REGISTRATOR_PERSON_NAME,
+            PARAM_ITEMS.REGISTRATOR_PERSON_PIN,
+        ),
+    )
+
+    CARD_REGISTRY_FOLDER_WAS_SET_NOT_FROM_POLIBASE_FOR_POLIBASE_PERSON = (
+        EventDescription(
+            "Карта пациента: {} добавлена не с помощью Полибейс",
+            LogMessageChannels.CARD_REGISTRY,
+            LogMessageFlags.SAVE_ONCE,
+            (PARAM_ITEMS.PERSON_PIN,),
+        )
     )
 
     CARD_REGISTRY_SUITABLE_FOLDER_WAS_SET_FOR_POLIBASE_PERSON = EventDescription(
