@@ -23,7 +23,7 @@ class PASSWORD:
         )
         STRONG: PasswordSettings = PasswordSettings(
             10,
-            "#%+\-!=@()_",
+            r"#%+\-!=@()_",
             RULES.DEFAULT_ORDER_LIST,
             3,
             3,
@@ -35,6 +35,7 @@ class PASSWORD:
         PC: PasswordSettings = NORMAL
         EMAIL: PasswordSettings = NORMAL
 
+    @staticmethod
     def get(name: str) -> SETTINGS:
         return PASSWORD.__getattribute__(PASSWORD.SETTINGS, name)
 
