@@ -29,4 +29,8 @@ class ServiceRoleBase(Enum):
         elif isinstance(value, Hosts):
             self.host = value.value
         elif isinstance(value, Host):
-            self.host = value.name
\ No newline at end of file
+            self.host = value.name
+            
+    @property
+    def NAME(self) -> str | None:
+        return self.value.name
\ No newline at end of file
