@@ -203,7 +203,7 @@ class RPC:
                                 service_information_name
                             ]
                         )
-                        DataTool.rpc_unrepresent(
+                        DataTool.rpc_decode(
                             RPC.call_service(
                                 subscriber_information.service_information,
                                 SC.unsubscribe,
@@ -306,7 +306,7 @@ class RPC:
                         )
                         if subscriber_information.available:
                             out_result = ParameterList(
-                                DataTool.rpc_unrepresent(
+                                DataTool.rpc_decode(
                                     RPC.call_service(
                                         service_information,
                                         sc,
@@ -448,11 +448,11 @@ class RPC:
             parameters = command.parameters
 
             if ne(parameters):
-                parameters = DataTool.rpc_unrepresent(parameters)
+                parameters = DataTool.rpc_decode(parameters)
             RPC.context = context
             result: Any = self.internal_call_handler(command.name, parameters, context)
             if n(context.code()):
-                return pb2.rpcCommandResult(data=DataTool.rpc_represent(result)) # type: ignore
+                return pb2.rpcCommandResult(data=DataTool.rpc_encode(result)) # type: ignore
             return result
 
     class Service(IService):
@@ -667,7 +667,7 @@ class RPC:
             for service_description in self.subscribtions_map:
                 for sc in self.subscribtions_map[service_description]:
                     if sc in command_list:
-                        DataTool.rpc_unrepresent(
+                        DataTool.rpc_decode(
                             RPC.call_service(
                                 service_description, SC.unsubscribe, (self.description,)
                             )
@@ -766,7 +766,7 @@ class RPC:
                         timeout = CONST_RPC.TIMEOUT
             return (
                 RPC.CommandClient(service_host, service_port)  # type: ignore
-                .call_command(sc.name, DataTool.rpc_represent(parameters), timeout)
+                .call_command(sc.name, DataTool.rpc_encode(parameters), timeout)
                 .data
             )
         except grpc.RpcError as exception:
