@@ -3,6 +3,7 @@ import os
 import sys
 import json
 import shlex
+import pycron
 import socket
 import string
 import random
@@ -11,9 +12,9 @@ import pathlib
 import calendar
 import platform
 import dataclasses
-from os import walk
 from enum import Enum
 from time import sleep
+from os import walk, scandir
 from operator import itemgetter
 from contextlib import contextmanager
 from inspect import isfunction, isclass
@@ -21,6 +22,7 @@ from typing import Any, Callable, Tuple, List
 from datetime import date, datetime, timedelta
 
 from pih.consts.password import RULES
+from pih.consts.style import *
 from pih.consts.date_time import DATE_TIME
 from pih.consts.names import FieldCollectionAliases
 
@@ -37,10 +39,13 @@ from pih.collections import (
 
 
 def if_else(
-    check_value: bool,
+    check_value: bool | None,
     true_value: Callable[[], Any] | Any,
     false_value: Callable[[], Any] | Any = None,
+    none_value: Callable[[], Any] | Any = None,
 ) -> Any:
+    if n(check_value) and nn(none_value):
+        return none_value() if callable(none_value) else none_value
     return (
         (true_value() if callable(true_value) else true_value)
         if check_value
@@ -86,6 +91,46 @@ def j(value: tuple[Any, ...] | list[Any], splitter: str = "") -> str:
     return splitter.join(DataTool.map(str, DataTool.filter(nn, value)))
 
 
+def nnl(value: Any) -> list:
+    return value
+
+
+def nna(value: Any) -> Any:
+    return value
+
+
+def nnd(value: Any) -> dict:
+    return value
+
+
+def nnt(value: T | None) -> T:
+    return value
+
+
+def nns(value: Any, default_value: str | None = None) -> str:
+    if value == "":
+        return value
+    return value or default_value
+
+
+def nnb(value: Any) -> bytes:
+    return value
+
+
+def nni(value: Any, default_value: int | None = None) -> int:
+    if n(value) and nn(default_value):
+        return nni(default_value)
+    return value
+
+
+def nndt(value: Any) -> datetime:
+    return value
+
+
+def nnf(value: Any) -> float:
+    return value
+
+
 def jnl(value: tuple[Any, ...] | list[Any]) -> str:
     return j(value, nl())
 
@@ -100,9 +145,7 @@ def js(value: tuple[Any, ...] | list[Any], aditional_splitter: str = "") -> str:
 
 class ParameterList:
     def __init__(self, value: Any):
-        self.values = (
-            value if isinstance(value, (list, tuple)) else [value]
-        )
+        self.values = value if isinstance(value, (list, tuple)) else [value]
         self.index = 0
 
     def next(self, object: Any = None, default_value: Any = None) -> Any:
@@ -210,7 +253,7 @@ class DataTool:
 
     @staticmethod
     def every(
-        action_function: Callable[[T, int | None], None],
+        action_function: Callable[[T, int], None] | Callable[[T], None],
         data: list[T],
         use_index: bool = False,
     ) -> list[T]:
@@ -242,6 +285,21 @@ class DataTool:
     def filter(function: Callable[[Any], bool], value: list[Any] | Any) -> list[Any]:
         return [] if n(value) else list(filter(function, DataTool.as_list(value)))
 
+    @staticmethod
+    def filter_by_string(
+        string: str,
+        value: list[Any] | Any,
+        label_function: Callable[[Any], str] | None = None,
+    ) -> list[Any]:
+        string = lw(string)
+        return DataTool.filter(
+            lambda item: (
+                lw(item if n(label_function) else label_function(item)).find(string)
+            )
+            != -1,
+            value,
+        )
+
     @staticmethod
     def as_value(
         function_or_value: Callable[[], str] | Callable[[Any], str] | str | None,
@@ -265,7 +323,7 @@ class DataTool:
         return BitMask.set(value_list)
 
     @staticmethod
-    def by_index(data: list | None, index: int, default_value: Any = None) -> Any:
+    def by_index(data: list | None, index: int = 0, default_value: Any = None) -> Any:
         if n(data):
             return default_value
         if len(data) <= index:
@@ -273,7 +331,9 @@ class DataTool:
         return data[index]
 
     @staticmethod
-    def rpc_represent(data: dict | None, ensure_ascii: bool = True) -> str | None:
+    def rpc_encode(
+        data: dict[str, Any] | None, ensure_ascii: bool = True
+    ) -> str | None:
         return (
             None
             if n(data)
@@ -281,7 +341,7 @@ class DataTool:
         )
 
     @staticmethod
-    def rpc_unrepresent(value: str | None) -> dict[str, Any] | None:
+    def rpc_decode(value: str | None) -> dict[str, Any] | None:
         return None if e(value) else json.loads(value)
 
     @staticmethod
@@ -290,7 +350,7 @@ class DataTool:
         class_type_holder: Any | Callable[[Any], Any] | None = None,
         first_data_item: bool = False,
     ) -> Result[Any]:
-        result_object: dict[str, Any] | None = DataTool.rpc_unrepresent(result_string)
+        result_object: dict[str, Any] | None = DataTool.rpc_decode(result_string)
         if n(result_object):
             return Result(None, None)
         data: dict = result_object["data"]  # type: ignore
@@ -453,7 +513,7 @@ class DataTool:
 
     @staticmethod
     def fill_data_from_rpc_str(data: T, source: str) -> T:
-        return DataTool.fill_data_from_source(data, DataTool.rpc_unrepresent(source))
+        return DataTool.fill_data_from_source(data, DataTool.rpc_decode(source))
 
     @staticmethod
     def get_first_item(
@@ -500,11 +560,12 @@ class DataTool:
 
     @staticmethod
     def check(
-        check_value: bool,
+        check_value: bool | None,
         true_value: Callable[[], Any] | Any,
         false_value: Callable[[], Any] | Any = None,
+        none_value: Callable[[], Any] | Any = None,
     ) -> Any:
-        return if_else(check_value, true_value, false_value)
+        return if_else(check_value, true_value, false_value, none_value)
 
     @staticmethod
     def check_not_none(
@@ -583,7 +644,7 @@ class FullNameTool:
         )
 
     @staticmethod
-    def is_equal(fn_a: FullName, fn_b: FullName) -> bool:
+    def is_equal_by_fullname(fn_a: FullName, fn_b: FullName) -> bool:
         return (
             fn_a.first_name == fn_b.first_name
             and fn_a.middle_name == fn_b.middle_name
@@ -637,6 +698,10 @@ class BitMask:
                 value |= bit.value
         return value
 
+    @staticmethod
+    def set_index(value: int, index: int) -> int:
+        return BitMask.add(value, 2**index)
+
     @staticmethod
     def set(bit: int | tuple[Enum, ...] | Enum | list[Enum] | list[int]) -> int:
         return BitMask.add(0, bit)
@@ -647,7 +712,7 @@ class BitMask:
 
     @staticmethod
     def has(
-        value: int | tuple[Enum, ...] | Enum | list[Enum] | list[int],
+        value: int | tuple[Enum, ...] | Enum | list[Enum] | list[int] | None,
         bit: int | tuple[Enum, ...] | Enum | list[Enum] | list[int],
     ) -> bool:
         if n(value):
@@ -672,7 +737,9 @@ class BitMask:
         return BitMask.has(value, pow(2, index))
 
     @staticmethod
-    def remove(value: int, bit: int | Enum) -> int:
+    def remove(value: int | tuple[Enum, ...], bit: int | Enum) -> int:
+        if not isinstance(value, int):
+            value = BitMask.value(value)
         if isinstance(bit, Enum):
             bit = bit.value
         if BitMask.has(value, bit):
@@ -804,6 +871,26 @@ class ResultTool:
         result.data = DataTool.every(action_function, result.data, use_index)
         return result
 
+    @staticmethod
+    def every_with_fields(
+        action_function: Callable[[T, int, FieldItemList], None] | Callable[[T], None],
+        result: Result[list[T]],
+        use_index: bool = False,
+    ) -> Result[list[T]]:
+        return (
+            ResultTool.every(
+                lambda item, index: action_function(item, index, result.fields),
+                result,
+                use_index,
+            )
+            if use_index
+            else ResultTool.every(
+                lambda item: action_function(item, result.fields),
+                result,
+                use_index,
+            )
+        )
+
     @staticmethod
     def do_while(result: Result[list[T]], check_function: Callable[[T], bool]) -> Any:
         result_data: Any = None
@@ -843,11 +930,13 @@ n = DataTool.is_none
 nn = DataTool.is_not_none
 
 
-def lw(value: str | list[str] | tuple[str, ...] | None) -> str:
+def lw(
+    value: str | list[str] | tuple[str, ...] | None
+) -> str | list[str] | tuple[str, ...]:
     if n(value):
         return ""
     if isinstance(value, str):
-        return value.lower()
+        return lw([value])[0]
     return DataTool.map(str.lower, value)
 
 
@@ -875,20 +964,24 @@ def separate_on_parts(value: Any) -> tuple[str, str, str]:
     return (left, strip_value, right)
 
 
-def i(value: Any) -> str:
-    if ne(value):
-        value = str(value).strip()
-        if value.find("_") == -1:
-            return j(("_", value, "_"))
-    return value or ""
-
-
 def b(value: Any) -> str:
-    if ne(value):
-        left, value, right = separate_on_parts(value)
-        if value.find("*") == -1:
-            return j((left, "*", value, "*", right))
-    return value or ""
+    if e(value):
+        return ""
+    return j((BOLD_BEGIN, str(value).strip(), BOLD_END))
+
+
+def i(value: Any) -> str:
+    if e(value):
+        return ""
+    return j((ITALICS_BEGIN, str(value).strip(), ITALICS_END))
+
+
+def surround_text_with(text: Any, value: str) -> str:
+    if ne(text):
+        left, text, right = separate_on_parts(text)
+        if text.find(value) == -1:
+            return j((left, value, text, value, right))
+    return text or ""
 
 
 def lnk(value: str) -> str:
@@ -911,9 +1004,44 @@ def escs(
 
 
 class ListTool:
+
     @staticmethod
     def diff(a: list[Any], b: list[Any]) -> list[Any]:
-        return [i for i in a + b if i not in a or i not in b]
+        return [i for i in a + b if not (i in a and i in b)]
+
+    @staticmethod
+    def list_str_diff(
+        a: list[str],
+        b: list[str],
+    ) -> list[str]:
+        def compare_function(value1: str, value2: list[str]) -> bool:
+            for item in value2:
+                if StringTool.contains(value1, item, True):
+                    return True
+            return False
+
+        return [
+            i for i in a + b if not (compare_function(i, a) and compare_function(i, b))
+        ]
+
+    @staticmethod
+    def intersection(a: list[Any], b: list[Any]) -> bool:
+        return len(ListTool.diff(a, b)) < (len(a) + len(b))
+
+    @staticmethod
+    def list_of_str_intersection(a: list[str], b: list[str]) -> bool:
+        return ListTool.list_str_intersection_ratio(a, b) < (len(a) + len(b))
+
+    @staticmethod
+    def list_str_intersection_ratio(
+        a: list[str],
+        b: list[str],
+    ) -> int:
+        return len(ListTool.list_str_diff(a, b))
+
+    @staticmethod
+    def str_list_equal(a: list[str], b: list[str]) -> bool:
+        return len(ListTool.list_str_diff(a, b)) == 0
 
     @staticmethod
     def to_dict_with_none_value(
@@ -935,15 +1063,134 @@ class ListTool:
 
 
 class StringTool:
+
     @staticmethod
-    def contains(value1: str, value2: str) -> bool:
+    def bold(value: Any) -> str:
+        return j((BOLD_BEGIN, str(value).strip(), BOLD_END))
+
+    @staticmethod
+    def italics(value: Any) -> str:
+        return j((ITALICS_BEGIN, str(value).strip(), ITALICS_END))
+
+    @staticmethod
+    def split(value: str, delimiters: tuple[str, ...] | str) -> list[str]:
+        if isinstance(delimiters, str):
+            delimiters = (delimiters,)
+        for delimiter in delimiters:
+            value = js(value.split(delimiter))
+        return StringTool.space_format(value).split(" ")
+
+    @staticmethod
+    def _comparation_ratio_by_tokens(
+        a: str,
+        b: str,
+        token_delimiter: str | tuple[str, ...] = " ",
+    ) -> tuple[int, list[str], list[str]]:
+        if isinstance(token_delimiter, str):
+            token_delimiter = (token_delimiter,)
+        a = lw(a)
+        b = lw(b)
+        a_list: list[str] = StringTool.split(a, token_delimiter)
+        b_list: list[str] = StringTool.split(b, token_delimiter)
+        a_list = ListTool.not_empty_items(list(set(a_list)))
+        b_list = ListTool.not_empty_items(list(set(b_list)))
+        return (
+            ListTool.list_str_intersection_ratio(a_list, b_list),
+            a_list,
+            b_list,
+        )
+
+    @staticmethod
+    def equal_by_tokens(
+        a: str,
+        b: str,
+        token_delimiter: str | tuple[str, ...] = " ",
+    ) -> bool:
+        return StringTool._comparation_ratio_by_tokens(a, b, token_delimiter)[0] == 0
+
+    @staticmethod
+    def intersection_by_tokens(
+        a: str,
+        b: str,
+        token_delimiter: str | tuple[str, ...] = " ",
+    ) -> bool:
+        result: tuple[int, list[str], list[str]] = (
+            StringTool._comparation_ratio_by_tokens(a, b, token_delimiter)
+        )
+        return result[0] < (len(result[1]) + len(result[2]))
+
+    @staticmethod
+    def full_right_intersection_by_tokens(
+        a: str,
+        b: str,
+        token_delimiter: str | tuple[str, ...] = " ",
+    ) -> bool:
+        if a.find(b) != -1:
+            return True
+        result: tuple[int, list[str], list[str]] = (
+            StringTool._comparation_ratio_by_tokens(a, b, token_delimiter)
+        )
+        return result[0] == (len(result[1]) - len(result[2]))
+
+    @staticmethod
+    def has_one_of(text: str, variants: list[str]) -> bool:
+        def mapper(value: str) -> str:
+            value = value.replace(" ", "[ ,]*")
+            value_variable_list: list[str] = ListTool.not_empty_items(value.split("|"))
+            if len(value_variable_list) > 1:
+                value = j(
+                    (
+                        value_variable_list[0],
+                        r"(?:\(|",
+                        j(value_variable_list[1:], "|"),
+                        "|$)",
+                    )
+                )
+            return value
+
+        return nn(
+            re.search(
+                j(
+                    (
+                        r"\b(",
+                        j(
+                            DataTool.map(
+                                mapper,
+                                variants,
+                            ),
+                            "|",
+                        ),
+                        r")\b",
+                    )
+                ),
+                text,
+                flags=re.IGNORECASE,
+            )
+        )
+
+    @staticmethod
+    def space_format(value: str | None) -> str | None:
+        if n(value):
+            return value
+        return nns(value).replace("\xa0", " ")
+
+    @staticmethod
+    def split_by_space(value: str | None) -> list[str]:
+        return StringTool.space_format((value or "")).split(" ")
+
+    @staticmethod
+    def contains(value1: str, value2: str, start_with: bool = False) -> bool:
         if n(value1) or n(value2):
             return False
+
+        def eq(value1: str, value2: str) -> bool:
+            return (
+                value1.startswith(value2) if start_with else value1.find(value2) != -1
+            )
+
         value1 = value1.lower()
         value2 = value2.lower()
-        return (
-            value2.find(value1) if len(value2) > len(value1) else value1.find(value2)
-        ) != -1
+        return eq(value2, value1) if len(value2) > len(value1) else eq(value1, value2)
 
     @staticmethod
     def equal(value1: str, value2: str) -> bool:
@@ -1100,6 +1347,20 @@ class StringTool:
 
 
 class DateTimeTool:
+
+    @staticmethod
+    def is_now(cron_string: str, value: datetime | None = None) -> bool:
+        cron_string = cron_string.strip()
+        as_time_list: list[str] = cron_string.split(":")
+        if len(as_time_list) > 1:
+            cron_string = js((as_time_list[1], as_time_list[0], "*", "*", "*"))
+        else:
+            length: int = len(cron_string.split(" "))
+            need_length: int = 5
+            if length < need_length:
+                cron_string = j((cron_string, " *" * (need_length - length)))
+        return pycron.is_now(cron_string, value)
+
     @staticmethod
     def day_count(date: date | datetime, month_count: int) -> int:
         result: int = 0
@@ -1112,7 +1373,6 @@ class DateTimeTool:
                 current_month = 1
             result += calendar.monthrange(year, current_month)[1]
             current_month += 1
-        # return month_count*31
         return result
 
     @staticmethod
@@ -1124,26 +1384,22 @@ class DateTimeTool:
         return value / 60 / 60 / 24
 
     @staticmethod
-    def yesterday() -> datetime:
-        return DateTimeTool.today(-1, as_datetime=True)
+    def yesterday(as_datetime: bool = False) -> datetime | date:
+        return DateTimeTool.today(-1, as_datetime=as_datetime)
 
     @staticmethod
     def begin_date(value: datetime | date | None = None) -> datetime | date:
         value = value or DateTimeTool.today(as_datetime=True)
-        return (
-            value.replace(hour=0, minute=0, second=0, microsecond=0)
-            if isinstance(value, datetime)
-            else value
-        )
+        if isinstance(value, date):
+            value = datetime.combine(value, datetime.min.time())
+        return value.replace(hour=0, minute=0, second=0, microsecond=0)
 
     @staticmethod
     def end_date(value: datetime | date | None = None) -> datetime | date:
         value = value or DateTimeTool.today(as_datetime=True)
-        return (
-            value.replace(hour=23, minute=59, second=59, microsecond=0)
-            if isinstance(value, datetime)
-            else value
-        )
+        if isinstance(value, date):
+            value = datetime.combine(value, datetime.min.time())
+        return value.replace(hour=23, minute=59, second=59, microsecond=0)
 
     @staticmethod
     def timestamp() -> int:
@@ -1165,7 +1421,7 @@ class DateTimeTool:
 
     @staticmethod
     def datetime_to_string(
-        date: datetime | None, format: str | None = None
+        date: datetime | date | None, format: str | None = None
     ) -> str | None:
         if n(date):
             return None
@@ -1174,8 +1430,10 @@ class DateTimeTool:
         )
 
     @staticmethod
-    def date_to_string(date: datetime, format: str | None = None) -> str:
-        return DateTimeTool.datetime_to_string(date.date(), format)
+    def date_to_string(date: datetime | date, format: str | None = None) -> str:
+        return DateTimeTool.datetime_to_string(
+            date.date() if isinstance(date, datetime) else date, format
+        )
 
     @staticmethod
     def to_date_string(isoformat_date_string: str) -> str:
@@ -1219,14 +1477,14 @@ class DateTimeTool:
 
     @staticmethod
     def datetime_from_string(
-        value: str | None, format: str | None = None
+        value: datetime | None, format: str | None = None
     ) -> datetime | None:
         if e(value):
             return None
         return DataTool.check_not_none(
             format,
-            lambda: datetime.strptime(value, format),
-            lambda: datetime.fromisoformat(value),
+            lambda: datetime.strptime(nnt(value), nnt(format)),
+            lambda: datetime.fromisoformat(nnt(value)),
         )
 
     @staticmethod
@@ -1249,7 +1507,9 @@ class DateTimeTool:
         return DateTimeTool.datetime_or_date_from_string(value, as_date=True)
 
     @staticmethod
-    def is_equal_by_time(date: datetime, value: tuple | list | datetime) -> bool | None:
+    def is_equal_by_time(
+        date: datetime, value: datetime | tuple[int, int] | list[int]
+    ) -> bool | None:
         if isinstance(value, (tuple, list)):
             return date.hour == value[0] and date.minute == value[1]
         if isinstance(value, datetime):
@@ -1276,13 +1536,32 @@ class TranslateTool:
 
 
 class PathTool:
+
+    @staticmethod
+    def directory_size(path: str) -> int:
+        result = 0
+        dirs = [path]
+        while dirs:
+            next_dir = dirs.pop()
+            with scandir(next_dir) as it:
+                for entry in it:
+                    if entry.is_dir(follow_symlinks=False):
+                        dirs.append(entry.path)
+                    else:
+                        result += entry.stat(follow_symlinks=False).st_size
+        return result
+
     @staticmethod
     def path(value: str) -> str:
         return value.replace("\\", "/")
 
     @staticmethod
-    def adapt_for_windows(value: str) -> str:
-        return value.replace("/", "\\")
+    def for_windows(value: str) -> str:
+        separator: str = "\\"
+        value = value.replace("/", separator)
+        if value.find(":") == -1 and not value.startswith(separator * 2):
+            value = j((separator * 2, value))
+        return value
 
     @staticmethod
     def exists(path: str) -> bool:
@@ -1328,7 +1607,9 @@ class PathTool:
         return os.path.join(sys.path[0], file_name)
 
     @staticmethod
-    def add_extension(file_path: str | None = None, extension: str | None = None) -> str:
+    def add_extension(
+        file_path: str | None = None, extension: str | None = None
+    ) -> str:
         if nn(file_path):
             dot_index: int = file_path.find(".")
             if dot_index != -1:
